# PreliZ
Tools to help you pick a prior.


**This package is very new and all of its features are experimental, not yet well tested, and subject to change without notice.**


## Contributions
PreliZ is a community project and welcomes contributions.
Additional information can be found in the [Contributing Readme](https://github.com/arviz-devs/preliz/blob/main/CONTRIBUTING.md)


## Code of Conduct
PreliZ wishes to maintain a positive community. Additional details
can be found in the [Code of Conduct](https://github.com/arviz-devs/preliz/blob/main/CODE_OF_CONDUCT.md)

## Donations
PreliZ, as other ArviZ-devs projects, is a non-profit project under the NumFOCUS umbrella. If you want to support PreliZ financially, you can donate [here](https://numfocus.org/donate-to-arviz).

## Sponsors
[![NumFOCUS](https://www.numfocus.org/wp-content/uploads/2017/07/NumFocus_LRG.png)](https://numfocus.org)
